@@ -22,12 +22,14 @@ def config_server_add(ctx, address):
     Add your ElasticSearch server.
     """
     config_file = os.path.expanduser('~/.horuz/horuz.cfg')
+    os.makedirs(os.path.dirname(config_file), exist_ok=True)
     address = click.prompt(
         "Please enter the address of your ElasticSearch",
         default=address
     )
     with open(config_file, 'w') as cfg:
         cfg.write(address)
+        ctx.log('ElasticSearch is connected now to {}'.format(address))
 
 
 @cli.command("server:status")
